C+
C NAME:
C	ForeignI2Arg
C PURPOSE:
C	Extract integer*2 value from keyword/value pair
C CALLING SEQUENCE:
	subroutine ForeignI2Arg(cStr,cName,Def,Val)
C INPUTS:
C	cStr		character*(*)	string with keywords
C	cName		character*(*)	name of keyword
C	Def		integer*2	value assigned if keyword not present
C OUTPUTS:
C	Val		integer*2	value of keyword
C CALLS:
C	ForeignI2ArgN
C MODIFICATION HISTORY:
C	NOV-2004, Paul Hick (UCSD/CASS)
C	JUN-2006, Paul Hick (UCSD/CASS; pphick@ucsd.edu)
C	    Old ForeignI2Arg was used to make ForeignI2ArgN.
C	    New ForeignI2Arg is one-line interface to ForeignI2ArgN
C-
	    character	cStr *(*)
	    character	cName*(*)
	    integer*2	Def
	    integer*2	Val

	nVal = 1
	call ForeignI2ArgN(cStr,cName,Def,nVal,Val)

	return
	end
